@@ -60,7 +60,7 @@ class fMMS_config:
 		if self.get_version() == None:
 			self.set_version("Unknown")
 		if self.get_connmode() == None:
-			self.set_connmode(CONNMODE_ICDSWITCH)
+			self.set_connmode(CONNMODE_FORCESWITCH)
 		if self.get_db_path() == None:
 			self.set_db_path("/home/user/.fmms/mms.db")
 		if not self.get_useragent():
@@ -81,7 +81,7 @@ class fMMS_config:
 		if self.get_firstlaunch() == 0:
 			self.set_firstlaunch(1)
 			self.set_img_resize_width(240)
-			self.set_connmode(CONNMODE_ICDSWITCH)
+			self.set_connmode(CONNMODE_FORCESWITCH)
 
 	def get_old_mmsc(self):
 		return self.client.get_string(self._fmmsdir + 'mmsc')
@@ -97,6 +97,12 @@ class fMMS_config:
 		
 	def get_connmode(self):
 		return self.client.get_int(self._fmmsdir + "connmode")
+		
+	def get_last_ui_dir(self):
+		return self.client.get_string(self._fmmsdir + "lastuidir")
+		
+	def set_last_ui_dir(self, path):
+		self.client.set_string(self._fmmsdir + "lastuidir", path)
 	
 	def set_db_path(self, path):
 		self.client.set_string(self._fmmsdir + "db", path)
@@ -236,6 +242,7 @@ class fMMS_config:
 		self.client.set_string('/system/osso/connectivity/IAP/' + apn + '/gprs_accesspointname', settings['apn'])
 		self.client.set_string('/system/osso/connectivity/IAP/' + apn + '/gprs_username', settings['user'])
 		self.client.set_string('/system/osso/connectivity/IAP/' + apn + '/gprs_password', settings['pass'])
+		self.client.set_string('/system/osso/connectivity/IAP/' + apn + '/type', "GPRS")
 		
 		if settings.get('proxy', "") == "" or not settings.get('proxy'):
 			self.client.set_string('/system/osso/connectivity/IAP/' + apn + '/proxytype', "NONE")
@@ -295,7 +302,9 @@ class fMMS_config:
 	def create_new_apn(self):
 		""" Create a new APN for MMS usage. """
 		# gconf_list_all_dirs is pretty random...
-		apn = "0000-0000-0000-0000"
+		#apn = "0000-0000-0000-0000"
+		import uuid
+		apn = str(uuid.uuid4())
 		self.client.add_dir('/system/osso/connectivity/IAP/' + apn, gconf.CLIENT_PRELOAD_NONE)
 		self.client.set_string('/system/osso/connectivity/IAP/' + apn + "/type", "GPRS")
 		self.client.set_string('/system/osso/connectivity/IAP/' + apn + "/name", "MMS")
@@ -428,6 +437,14 @@ class fMMS_config:
 			self.set_apn(secondary)
 		else:
 			return iaps[0]
+
+	def reset_all_settings(self):
+		log.info("removing connectivity settings: /system/osso/connectivity/IAP/%s" % self.get_apn())
+		self.client.recursive_unset('/system/osso/connectivity/IAP/' + self.get_apn(), gconf.UNSET_INCLUDING_SCHEMA_NAMES)
+		fmmsdir = self._fmmsdir.rstrip('/')
+		log.info("removing fmms application settings: %s" % fmmsdir)
+		self.client.recursive_unset(fmmsdir, gconf.UNSET_INCLUDING_SCHEMA_NAMES)
+		return True
 		
 if __name__ == '__main__':
 	config = fMMS_config()
