@@ -19,6 +19,7 @@ import gettext
 
 import dbus
 import pynotify
+from gnome import gnomevfs
 
 from mms import message
 from mms.message import MMSMessage
@@ -30,7 +31,6 @@ import connectors
 import logging
 log = logging.getLogger('fmms.%s' % __name__)
 
-
 class PushHandler:
 	def __init__(self):
 		self.cont = fMMSController.fMMS_controller()
@@ -70,7 +70,6 @@ class PushHandler:
 		
 		(data, sndr, url, trans_id) = self.cont.decode_mms_from_push(binarydata)
 		
-		
 		ch = ContactH.ContactHandler()
 		sndr = ch.get_displayname_from_number(sndr)
 		
@@ -119,11 +118,13 @@ class PushHandler:
 		interface.PlayEvent({'time': 0, 'category': 'email-message'}, "fmms")
 		note.show()
 
-	def _get_mms_message(self, location, transaction):
+	def _get_mms_message(self, location, transaction, controller=0):
 		# this method should be a critical section
-		connector = connectors.MasterConnector()
+		if controller != 0:
+			self.cont = controller
+		connector = connectors.MasterConnector(self.cont)
 		connector.connect(location)
-				
+		
 		try:
 			dirname = self.__get_mms_message(location, transaction)
 		except:
@@ -224,34 +225,62 @@ class PushHandler:
 class MMSSender:
 	""" class for sending an mms """
 	
-	def __init__(self, number=None, subject=None, msg=None, attachment=None, sender=None, customMMS=None, setupConn=False):
+	def __init__(self, number=None, subject=None, msg=None, attachment=None, sender=None, customMMS=None, setupConn=False, controller=0):
 		self.customMMS = customMMS
-		self.cont = fMMSController.fMMS_controller()
+		if controller != 0:
+			self.cont = controller
+		else:
+			self.cont = fMMSController.fMMS_controller()
 		self.config = self.cont.config
 		self.setupConn = setupConn
 		if customMMS == None:
 			self.number = number
-			self.subject = subject
+			if msg == None:
+				msg = ""
 			self.message = msg
+			if subject == '' or subject == None:
+				subject = self.message[:15].replace('\n', '')
+				if len(self.message) > 15:
+					subject += "..."
+				if len(subject) == 0:
+					subject = "MMS"
+			self.subject = subject
 			self.attachment = attachment
 			self._mms = None
 			self._sender = sender
 			self.createMMS()
 			if self.setupConn == True:
-				self.connector = connectors.MasterConnector()
-				self.connector.connect()
-				
-	    
+				self.connector = connectors.MasterConnector(self.cont)
+				try:
+					self.connector.connect()
+				except:
+					raise
+
 	def createMMS(self):
 		slide = message.MMSMessagePage()
 		if self.attachment != None:
-			slide.addImage(self.attachment)
+			try:
+				filetype = gnomevfs.get_mime_type(self.attachment)
+			except:
+				filetype = "unknown"
+			if filetype.startswith("audio"):
+				slide.addAudio(self.attachment)
+			elif filetype.startswith("video"):
+				slide.addVideo(self.attachment)
+			else:
+				slide.addImage(self.attachment)
 		slide.addText(self.message)
 
 		self._mms = message.MMSMessage()
 		self._mms.headers['Subject'] = self.subject
 		if "@" in self.number:
 			self._mms.headers['To'] = str(self.number)
+		elif ";" in self.number:
+			fullnr = "";
+			nr = self.number.split(";")
+			for val in nr:
+				fullnr = "%s%s" % (fullnr, (val.strip() + '/TYPE=PLMN;'))
+			self._mms.headers['To'] = str(fullnr).rstrip(";")
 		else:
 			self._mms.headers['To'] = str(self.number) + '/TYPE=PLMN'
 		if self._sender == '0':
@@ -290,9 +319,8 @@ class MMSSender:
 		socket.setdefaulttimeout(120)
 		
 		headers = {'Content-Type':'application/vnd.wap.mms-message', 'User-Agent' : self.config.get_useragent(), 'x-wap-profile' : 'http://mms.frals.se/n900.rdf'}
-		#headers = {'Content-Type':'application/vnd.wap.mms-message'}
 		if proxyurl == "" or proxyurl == None:
-			print "connecting without proxy"
+			log.info("connecting without proxy")
 			mmsc = mmsc.lower()
 			mmsc = mmsc.replace("http://", "")
 			mmsc = mmsc.rstrip('/')
@@ -309,7 +337,7 @@ class MMSSender:
 			conn.request('POST', mmsc, mms, headers)
 
 		if customData == None:			
-			cont = fMMSController.fMMS_controller()
+			cont = self.cont
 			path = cont.save_binary_outgoing_mms(mms, self._mms.transactionID)
 			message = cont.decode_binary_mms(path)
 			mmsid = cont.store_outgoing_mms(message)	
@@ -330,11 +358,9 @@ class MMSSender:
 				if outparsed['Response-Status'] == "Ok":
 					pushid = cont.store_outgoing_push(outparsed)
 					cont.link_push_mms(pushid, mmsid)
-				
 		except Exception, e:
-			print type(e), e
+			#print type(e), e
 			outparsed = out
-			
 		log.info("MMSC RESPONDED: %s", outparsed)
 		
 		return res.status, res.reason, outparsed, parsed
